'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getChangelogInfo = getChangelogInfo;
exports.saveChangelogInfo = saveChangelogInfo;

var _path = require('path');

var _glob = require('glob');

var _fsExtra = require('fs-extra');

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _migrations = require('./migrations');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getChangelogInfo(config) {
  ensureInitializedProject(config);

  return _jsYaml2.default.safeLoad((0, _fsExtra.readFileSync)(getInfoFilePath(config)));
}

function saveChangelogInfo(config, newChangelogInfo) {
  var infoFilePath = (0, _path.join)(config.path, 'info.yml');

  return (0, _fsExtra.outputFileSync)(infoFilePath, _jsYaml2.default.safeDump(newChangelogInfo));
}

// Three cases may occur:
//   1. info.yml exists already -> we can exit, the project is setup correctly
//   2. info.yml does not exist and we have no changelog entry files yet -> new project, write
//      initial config and set migration version to latest since it's implicitly up-to-date
//   3. info.yml does not exist but we have changelog entry files already -> old project, with
//      implicit migration version -1 (since info.yml was introduced with the first migration)
function ensureInitializedProject(config) {
  if ((0, _fsExtra.existsSync)(getInfoFilePath(config))) {
    // Case 1
    return;
  }

  var hasEntries = (0, _glob.sync)((0, _path.join)(config.path, '**/*')).length > 0;

  saveChangelogInfo(config, {
    version: hasEntries
    // Case 3
    ? -1
    // Case 2
    : _migrations.CURRENT_VERSION
  });
}

function getInfoFilePath(config) {
  return (0, _path.join)(config.path, 'info.yml');
}