'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = getChangelogData;

var _path = require('path');

var _fsExtra = require('fs-extra');

var _groupBy = require('lodash/groupBy');

var _groupBy2 = _interopRequireDefault(_groupBy);

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _glob = require('glob');

var _utils = require('./utils');

var _getSortedChangelogVersions = require('./getSortedChangelogVersions');

var _getSortedChangelogVersions2 = _interopRequireDefault(_getSortedChangelogVersions);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var entryKinds = ['addition', 'change', 'fix', 'removal', 'deprecation', 'security'];

function getChangelogData(config) {
  return [getVersionChangelog(config, null)].concat(_toConsumableArray((0, _getSortedChangelogVersions2.default)(config).map(function (version) {
    return getVersionChangelog(config, version);
  })));
}

function getVersionChangelog(config, version) {
  return {
    version: version,
    entries: _extends({}, entryKinds.reduce(function (kinds, entryKind) {
      return _extends({}, kinds, _defineProperty({}, entryKind, []));
    }, {}), (0, _groupBy2.default)(getVersionChangelogFileNames(config, (0, _utils.stringifyVersion)(version)).map(function (entryFileName) {
      return (0, _fsExtra.readFileSync)(entryFileName).toString();
    }).map(_jsYaml2.default.safeLoad).sort(sortByComponent.bind(null, config)), 'kind'))
  };
}

function sortByComponent(config, entry1, entry2) {
  if (!entry1.component && !entry2.component) {
    return 0;
  }

  if (!entry1.component && entry2.component) {
    return 1;
  }

  if (entry1.component && !entry2.component) {
    return -1;
  }

  // $FlowFixMe: Checks above cover that
  return config.components[entry1.component].localeCompare(config.components[entry2.component]);
}

function getVersionChangelogFileNames(_ref, versionString) {
  var path = _ref.path;

  return (0, _glob.sync)((0, _path.join)(path, versionString, '*.yml'));
}