'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = defaultTemplate;

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var entryKindToReadable = {
  change: 'Changed',
  addition: 'Added',
  fix: 'Fixed',
  security: 'Security',
  removal: 'Removed',
  deprecation: 'Deprecated'
};

function defaultTemplate(helpers, changelog) {
  return ['# Changelog'].concat(_toConsumableArray(changelog.map(function (versionChangelog) {
    return renderVersionChangelog(helpers, versionChangelog);
  }))).join('\n\n');
}

function renderVersionChangelog(helpers, _ref) {
  var version = _ref.version,
      entries = _ref.entries;

  // $FlowFixMe: Object.keys() does not refine correctly based on type definition of keys
  var entryKeys = Object.keys(entries);

  return ['## Version `' + helpers.stringifyVersion(version) + '`'].concat(_toConsumableArray(entryKeys.map(function (entryKind) {
    return renderEntriesOfKind(helpers, entryKind, entries[entryKind]);
  }).filter(function (entry) {
    return entry;
  }))).join('\n\n');
}

function renderEntriesOfKind(helpers, kind, entries) {
  if (entries.length === 0) {
    return '';
  }

  return ['### ' + entryKindToReadable[kind]].concat(_toConsumableArray(entries.map(function (_ref2) {
    var component = _ref2.component,
        description = _ref2.description;

    var componentLabel = component ? '**' + helpers.readableComponent(component) + ':** ' : '';

    return '- ' + componentLabel + description;
  }))).join('\n');
}